#
#  (C) Tenable Network Security
#

desc = "
Synopsis :

The remote host has an anti-virus software installed on it.

Description :

The remote host is running Sophos Antivirus, a commercial anti-virus

See also :

http://www.sophos.com/

Risk factor :

None";

if (description) 
{
  script_id(12215);
  script_version("$Revision: 1.7 $");

  script_name(english:"Sophos Anti Virus detection");
  script_summary(english:"Checks for Sophos AntiVirus version"); 
  script_description(english:desc);

  script_category(ACT_GATHER_INFO);
  script_family(english:"Windows");
  script_copyright(english:"This script is Copyright (C) 2007 Tenable Network Security");

  script_dependencies("smb_enum_services.nasl", "smb_hotfixes.nasl");
  script_require_keys("SMB/name", "SMB/login", "SMB/password", "SMB/registry_full_access", "SMB/transport");
  script_require_ports(139, 445);

  exit(0);
}


include("global_settings.inc");
include("smb_func.inc");

if (!get_kb_item("SMB/registry_full_access")) exit(0);


# Main processing starts here

# Connect to the appropriate share.
name    =  kb_smb_name();
port    =  kb_smb_transport();
if (!get_port_state(port)) exit(0);


login   =  kb_smb_login();
pass    =  kb_smb_password();
domain  =  kb_smb_domain();

soc = open_sock_tcp(port);
if (!soc) exit(0);

session_init(socket:soc, hostname:name);
rc = NetUseAdd(login:login, password:pass, domain:domain, share:"IPC$");
if (rc != 1) 
{
  NetUseDel();
  exit(0);
}

# Connect to remote registry.
hklm = RegConnectRegistry(hkey:HKEY_LOCAL_MACHINE);
if (isnull(hklm))
{
  NetUseDel();
  exit(0);
}
	
# Initialize variables to NULL

path = NULL;
prod_ver = NULL;
eng_ver = NULL;
#sigs_ver = NULL;

# Determine the software version

key = "SOFTWARE\Microsoft\Windows\CurrentVersion\Uninstall\{09C6BF52-6DBA-4A97-9939-B6C24E4738BF}";

key_h = RegOpenKey(handle:hklm, key:key, mode:MAXIMUM_ALLOWED);
if (!isnull(key_h)) 
{
  value = RegQueryValue(handle:key_h, item:"DisplayVersion");
  if (!isnull(value)) 
  {	
    prod_ver = value[1];
    set_kb_item(name:"Antivirus/Sophos/installed", value:TRUE);
  }	
  RegCloseKey(handle:key_h);
}

# Determine where it's installed.
key = "SOFTWARE\Sophos\SAVService\Application";

key_h = RegOpenKey(handle:hklm, key:key, mode:MAXIMUM_ALLOWED);
if (!isnull(key_h))
{
  value = RegQueryValue(handle:key_h, item:"path");
  if (!isnull(value)) path = value[1];
  RegCloseKey(handle:key_h);
}

RegCloseKey(handle:hklm);


if (isnull(path))
{
 NetUseDel();
 exit(0);
}

# If it is installed find the engine version from veex.dll
if (!isnull(path))
{
share = ereg_replace(pattern:"^([A-Za-z]):.*", replace:"\1$", string:path);
dll_file =  ereg_replace(pattern:"^[A-Za-z]:(.*)", replace:"\1\veex.dll", string:path);

NetUseDel(close:FALSE);

rc = NetUseAdd(login:login, password:pass, domain:domain, share:share);
if (rc != 1)
{
  NetUseDel();
  exit(0);
}

fh = CreateFile(
  file:dll_file,
  desired_access:GENERIC_READ,
  share_mode:FILE_SHARE_READ,
  create_disposition:OPEN_EXISTING
);

if (!isnull(fh))
{
  v = GetFileVersion(handle:fh);	
  eng_ver = string(v[0],".",v[1],".",v[2],".",v[3]);
}

}
NetUseDel();

# Generate report.
trouble = 0;
latest_prod_ver="6.5.5";
#latest_sigs_ver="4.14";
latest_eng_ver="2.45.3";

# - general info.
info = 'Sophos Antivirus is installed on the remote host :\n' +
       '\n' +
       '  Installation Path  : ' + path + '\n';
if (prod_ver) info += '  Product version    : ' + prod_ver + '\n';
if (eng_ver)  info += '  Engine version     : ' + eng_ver  + '\n';
#if (sigs_ver) info += '  Virus signatures   : ' + sigs_ver + '\n';
info += '\n';

# - product out of date?
if (!isnull(prod_ver))
{
  ver = split(prod_ver, sep:'.', keep:FALSE);
  for (i=0; i<max_index(ver); i++)
    ver[i] = int(ver[i]);

  fix = split(latest_prod_ver, sep:'.', keep:FALSE);
  for (i=0; i<max_index(fix); i++)
    fix[i] = int(fix[i]);

  for (i=0; i<max_index(ver); i++)
    if (!isnull(fix[i]) && ver[i] < fix[i])
    {
      info += 'The version of Sophos installed on the remote host is out-of-date -\n' +
              'the last known update from the vendor is ' + latest_prod_ver + '\n';
      trouble++;
      break;
    }
    else if (isnull(fix[i]) || ver[i] > fix[i])
      break;
}
# - virus signatures out of date?
#if (!isnull(sigs_ver))
#{
#  ver = split(sigs_ver, sep:'.', keep:FALSE);
#  for (i=0; i<max_index(ver); i++)
#    ver[i] = int(ver[i]);
#
#  fix = split(latest_sigs_ver, sep:'.', keep:FALSE);
#  for (i=0; i<max_index(fix); i++)
#    fix[i] = int(fix[i]);

 # for (i=0; i<max_index(ver); i++)
#    if (!isnull(fix[i]) && ver[i] < fix[i])
#    {
#      info += 'The virus signatures on the remote host are out-of-date - the last\n' +
#              'known update from the vendor is ' + latest_sigs_ver + '\n';
 #     trouble++;
#      break;
 #   }
#    else if (isnull(fix[i]) || ver[i] > fix[i])
#      break;
#}

# engine version out of date

if (!isnull(eng_ver))
{
  ver = split(eng_ver, sep:'.', keep:FALSE);
  for (i=0; i<max_index(ver); i++)
    ver[i] = int(ver[i]);

  fix = split(latest_eng_ver, sep:'.', keep:FALSE);
  for (i=0; i<max_index(fix); i++)
    fix[i] = int(fix[i]);

  for (i=0; i<max_index(ver); i++)
    if (!isnull(fix[i]) && ver[i] < fix[i])
    {
      info += 'The engine version on the remote host is out-of-date - the last\n' +
              'known update from the vendor is ' + latest_eng_ver + '\n';
      trouble++;
      break;
    }
    else if (isnull(fix[i]) || ver[i] > fix[i])
      break;
}

# - services running.
services = get_kb_item("SMB/svcs");
if (services && ("SAVService" >!< services))
{
  info += 'The Sophos Antivirus service is not running.\n';
  trouble++;
}

if (trouble) info += '\n' +
                     'As a result, the remote host might be infected by viruses.\n';

if (trouble)
{
  report = string(
    desc,
    "\n\n",
    "Plugin output :\n",
    "\n",
    info
  );
  security_hole(port:port, data:report);
}
else
{
  # nb: antivirus.nasl uses this in its own report.
  set_kb_item (name:"Antivirus/Sophos/description", value:info);
}
